#!/bin/sh
exe_name=$0
exe_dir=`dirname "$0"`
if [ "x$1" = "x" ]; then
  echo "Usage:
  run_normalization.sh Atlas Subject Output NumCPU PatchSIZE NumAtlasPatch 
                   NumSubjectPatch NumNN IsPrior IsSegmentation Type
  Atlas            Atlas volume, either NIFTI or RAW/XML pair, extension .nii or .xml
  Subject          Subject volume, either NIFTI or RAW/XML pair, extension .nii or .xml
  Output           Subject volume, either NIFTI or RAW/XML pair, extension .nii or .xml.
                   If subject is NIFTI, output should be NIFTI
  NumCPU           Number of parallel cpu cores to use
  PatchSize        Patch size, e.g., 3x3x3 or 3x3x1
  NumAtlasPatch    Number of atlas patches used to generate EM parameters, 
                   reasonable values are 1E4-2E5. Default 6E4
  NumSubjectPatch  Number of subject patches used to generate EM parameters, 
                   reasonable values are 1E4-2E5. Default 6E4
  NumNN            Number of nearest neighbors to be used. Very small number
                   leads to noisy result (FAST), very high number leads to very 
                   smooth result (SLOW). Reasonable values are 25-75.
  IsPrior          yes or no. If a histogram prior will be used. Default no
  IsSegmentation   yes or no. If a Fuzzy C-means segmentation prior will
                   be used. Default no
  Type             T1-w image modality, either SPGR or MPRAGE
  Change MCRROOT if necessary"
else
  ATLAS=$1
  SUBJ=$2
  OUTPUT=$3
  NUMCPU=$4
  PSIZE=$5
  NUMATLASPATCH=$6
  NUMSUBJECTPATCH=$7
  NUMNN=$8
  ISPRIOR=$9
  ISSEG=${10}
  TYPE=${11}
  MCRROOT=/home/roy/Matlab_Compiler_Runtime/v81
  echo "Using default Matlab Compiler Runtime root directory $MCRROOT"
  LD_LIBRARY_PATH=.:${MCRROOT}/runtime/glnxa64 ;
  LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRROOT}/bin/glnxa64 ;
  LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRROOT}/sys/os/glnxa64;
	MCRJRE=${MCRROOT}/sys/java/jre/glnxa64/jre/lib/amd64 ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/native_threads ; 
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/server ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/client ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE} ;  
  XAPPLRESDIR=${MCRROOT}/X11/app-defaults ;
  export LD_LIBRARY_PATH;
  export XAPPLRESDIR;
  echo ${exe_dir}/run_normalization $ATLAS $SUBJ $OUTPUT $NUMCPU $PSIZE $NUMATLASPATCH $NUMSUBJECTPATCH $NUMNN $ISPRIOR $ISSEG $TYPE
  ${exe_dir}/run_normalization $ATLAS $SUBJ $OUTPUT $NUMCPU $PSIZE $NUMATLASPATCH $NUMSUBJECTPATCH $NUMNN $ISPRIOR $ISSEG $TYPE
fi
exit

